pub fn validate_server_setup(msg: &ServerSetup) -> Result<(), SetupError>Expand description
Validate a SERVER_SETUP message.
Section 9.3.2.2 on PATH: “It MUST NOT be used by the server, or when WebTransport is used”, and a PATH received from the server closes the session with Invalid Path. Nothing else in a SERVER_SETUP is restricted by sender.
Errors
SetupError::WrongParameterRole if the server sent a PATH.